<?php
/**
 * Spacing Customizer Control
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WP_Customize_Control' ) ) {
	return null;
}

class Gutenbee_Customize_Image_BG_Control extends WP_Customize_Control {
	/**
	 * The type of control.
	 *
	 * @access public
	 * @var string
	 */
	public $type = 'gutenbee-image-bg';

	public $responsive = true;

	/**
	 * Display parallax options.
	 *
	 * @access public
	 * @var bool
	 */
	public $parallax = false;

	/**
	 * Display additional options (positioning, size, repeat, attachment).
	 *
	 * @access public
	 * @var bool
	 */
	public $additional_properties = true;

	/**
	 * Enqueue scripts and styles.
	 *
	 * @access public
	 * @return void
	 */
	public function enqueue() {
		$theme = wp_get_theme();

		wp_enqueue_script( $this->type . '-customize-control', get_theme_file_uri( '/inc/customizer/controls/image-bg/customizer.js' ), array( 'jquery' ), $theme->get( 'Version' ), true );
		wp_localize_script( $this->type . '-customize-control', 'customizerImageBgStrings', array(
			'selectImage' => esc_html__( 'Select an Image', 'gutenbee' ),
		) );
	}

	/**
	 * Refresh the parameters passed to the JavaScript via JSON.
	 *
	 * @access public
	 * @return void
	 */
	public function to_json() {
		parent::to_json();

		$this->json['id']                = $this->id;
		$this->json['canUpload']         = current_user_can( 'upload_files' );
		$this->json['repeatChoices']     = gutenbee_get_image_repeat_choices();
		$this->json['positionChoices']   = gutenbee_get_image_position_choices();
		$this->json['attachmentChoices'] = gutenbee_get_image_attachment_choices();
		$this->json['sizeChoices']       = gutenbee_get_image_size_choices();

		$value = $this->value();

		$this->json['values'] = $value;

		if ( ! empty( $value['image_id'] ) ) {
			$this->json['attachment'] = wp_prepare_attachment_for_js( $value['image_id'] );
		}

		$this->json['parallax']              = $this->parallax;
		$this->json['additional_properties'] = $this->additional_properties;
	}

	/**
	 * Don't render anything with PHP as rendering is handled via JS templates.
	 *
	 * @access public
	 */
	public function render_content() { }

	/**
	 * The Underscore (JS) template for this control's content.
	 *
	 * @access protected
	 * @return void
	 */
	protected function content_template() {
		?>
		<#
		var selectButtonId = _.uniqueId( 'gutenbee-image-bg-customize-control-button-' );
		var attachmentSrc = !data.attachment
			? ''
			: ((data.attachment.sizes.medium && data.attachment.sizes.medium.url) || data.attachment.sizes.full.url || data.attachment.icon || '');
		#>
		<div class="gutenbee-image-bg-control-wrap">
			<# if ( data.label ) { #>
				<label class="customize-control-title" for="{{ selectButtonId }}">{{ data.label }}</label>
			<# } #>

			<# if ( data.description ) { #>
				<span class="description customize-control-description">{{ data.description }}</span>
			<# } #>

			<div class="gutenbee-image-bg-control-group">
				<div class="gutenbee-image-bg-attachment-view gutenbee-image-bg-control-attachment-preview">
					<div class="gutenbee-image-bg-control-thumbnail">
						<img class="gutenbee-image-bg-control-attachment-thumb" alt="" src="">
					</div>

					<div class="actions">
						<# if ( data.canUpload ) { #>
						<button type="button" class="button remove-button"><?php esc_html_e( 'Remove', 'gutenbee' ); ?></button>
						<button type="button" class="button upload-button control-focus" id="{{ selectButtonId }}"><?php esc_html_e( 'Change image', 'gutenbee' ); ?></button>
						<# } #>
					</div>
				</div>

				<div class="gutenbee-image-bg-attachment-view gutenbee-image-bg-control-attachment-placeholder">
					<div class="gutenbee-image-bg-control-placeholder">
						<?php esc_html_e( 'No image selected', 'gutenbee' ); ?>
					</div>

					<div class="actions">
						<# if ( data.canUpload ) { #>
						<button type="button" class="button upload-button" id="{{ selectButtonId }}"><?php esc_html_e( 'Select image', 'gutenbee' ); ?></button>
						<# } #>
					</div>
				</div>
			</div>

			<div class="gutenbee-image-bg-control-group-grid">
				<# if( data.additional_properties ) { #>
					<div class="gutenbee-image-bg-control-group">
						<label for="{{data.id}}-image-bg-repeat">
							<?php esc_html_e( 'Image repeat', 'gutenbee' ); ?>
						</label>
						<select
							id="{{data.id}}-image-bg-repeat"
							data-property="repeat"
						>
							<# _.each( data.repeatChoices, function( label, val ) { #>
								<option value="{{val}}" {{{ (data.values.repeat === val) ? 'selected' : '' }}} >{{{label}}}</option>
							<# } ); #>
						</select>
					</div>

					<div class="gutenbee-image-bg-control-group">
						<label for="{{data.id}}-image-bg-position">
							<?php esc_html_e( 'Image position', 'gutenbee' ); ?>
						</label>
						<select
							id="{{data.id}}-image-bg-position"
							data-property="position"
						>
							<# _.each( data.positionChoices, function( label, val ) { #>
								<option value="{{val}}" {{{ (data.values.position === val) ? 'selected' : '' }}} >{{{label}}}</option>
							<# } ); #>
						</select>
					</div>

					<div class="gutenbee-image-bg-control-group">
						<label for="{{data.id}}-image-bg-attachment">
							<?php esc_html_e( 'Image attachment', 'gutenbee' ); ?>
						</label>
						<select
							id="{{data.id}}-image-bg-attachment"
							data-property="attachment"
						>
							<# _.each( data.attachmentChoices, function( label, val ) { #>
								<option value="{{val}}" {{{ (data.values.attachment === val) ? 'selected' : '' }}} >{{{label}}}</option>
							<# } ); #>
						</select>
					</div>

					<div class="gutenbee-image-bg-control-group">
						<label for="{{data.id}}-image-bg-size">
							<?php esc_html_e( 'Image size', 'gutenbee' ); ?>
						</label>
						<select
							id="{{data.id}}-image-bg-size"
							data-property="size"
						>
							<# _.each( data.sizeChoices, function( label, val ) { #>
								<option value="{{val}}" {{{ (data.values.size === val) ? 'selected' : '' }}} >{{{label}}}</option>
							<# } ); #>
						</select>
					</div>
				<# } #>

				<# if( data.parallax ) { #>
					<div class="gutenbee-image-bg-control-group">
						<input
							type="checkbox"
							id="{{data.id}}-parallax"
							value="1"
							{{{ data.values.parallax ? 'checked="checked"' : '' }}}
							data-property="parallax"
						>
						<label for="{{data.id}}-parallax">
							<?php esc_html_e( 'Enable Parallax', 'gutenbee' ); ?>
						</label>
					</div>

					<div class="gutenbee-image-bg-control-group">
						<label for="{{data.id}}-parallax-speed">
							<?php esc_html_e( 'Parallax Speed', 'gutenbee' ); ?>
						</label>
						<input
							type="number"
							id="{{data.id}}-parallax-speed"
							min="0"
							max="1"
							step="0.1"
							value="{{data.values.parallax_speed}}"
							data-property="parallax_speed"
						>
					</div>
				<# } #>
			</div>
		</div>
		<?php
	}
}
