/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Customizer preview changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ( $ ) {
	//
	// Layout
	//
	wp.customize( 'global_layout_type', function ( value ) {
		value.bind( function ( to ) {
			if ( to === 'boxed' ) {
				$( 'body' ).addClass( 'layout-boxed' );
			} else {
				$( 'body' ).removeClass( 'layout-boxed' );
			}
		} );
	} );

	wp.customize( 'global_layout_boxed_width', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.injectStylesheet(
				'global_layout_boxed_width',
				'.layout-boxed .page-wrap { width: ' + to.desktop + 'px; }'
			);
		} );
	} );

	wp.customize( 'global_layout_container_width', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.injectStylesheet(
				'global_layout_container_width',
				'@media (min-width: 1200px) { .container { width: ' + to.desktop + 'px; } }'
			);
		} );
	} );

	wp.customize( 'global_layout_content_width', function ( value ) {
		value.bind( function ( to ) {
			$( '.site-content > .container > .row > div:first-child' )
				.attr( 'class', 'col-lg-' + to.desktop + ' col-12' );
		} );
	} );

	wp.customize( 'global_layout_sidebar_width', function ( value ) {
		value.bind( function ( to ) {
			$( '.site-content > .container > .row > div:last-child' )
				.attr( 'class', 'col-lg-' + to.desktop + ' col-12' );
		} );
	} );

	//
	// Colors
	//

	// Backgrounds

	// Body background is handled by WordPress

	wp.customize( 'global_colors_boxed_background', function ( value ) {
		value.bind( function ( to ) {
			$( '.layout-boxed .page-wrap' ).css( 'background-color', to );
		} );
	} );

	wp.customize( 'global_colors_boxed_background_image', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createBackgroundImageStyles(
				'global_colors_boxed_background_image',
				'.layout-boxed .page-wrap',
				to
			);
		} );
	} );

	// Links
	wp.customize( 'global_colors_links', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_links', [
				{
					value: to,
					property: 'color',
					selectors: 'a',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_links_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_links_hover', [
				{
					value: to,
					property: 'color',
					selectors: 'a:hover',
				}
			]);
		} );
	} );

	// Global
	wp.customize( 'global_colors_accent', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_accent', [
				{
					value: to,
					property: 'color',
					selectors: '.site-logo a:hover,.head-content-slot-item .ci-font-icon:hover,.entry-title a:hover,.entry-meta a:hover,.entry-content-intro:first-letter,.ci-item-title a:hover,.navigation-main li:hover > a,.navigation-main li > a:focus,.navigation-main .current-menu-item > a,.navigation-main .current-menu-parent > a,.navigation-main .current-menu-ancestor > a,.navigation-main .current_page_item > a,.navigation-main .current_page_ancestor > a, .widget_meta li a:hover,.widget_pages li a:hover,.widget_categories li a:hover,.widget_archive li a:hover,.widget_nav_menu li a:hover,.widget_product_categories li a:hover,.woocommerce-widget-layered-nav li a:hover,.wc-tabs li.active a,.woocommerce-MyAccount-navigation .woocommerce-MyAccount-navigation-link a:hover,.product_list_widget .product-title:hover,.woocommerce-mini-cart-item > a:hover,li.wc-block-grid__product .wc-block-grid__product-link:hover,li.wc-block-grid__product .wc-block-grid__product-title a:hover,.wc-block-product-categories-list li a:hover,.wc-block-attribute-filter .wc-block-attribute-filter-list [type="checkbox"]:checked + label,.wc-block-attribute-filter .wc-block-attribute-filter-list label:hover',
				},
				{
					value: to,
					property: 'background-color',
					selectors: '.entry-tags a:hover,.tag-cloud-link:hover,.select2-container.select2-container--default  .select2-results__option[data-selected=true],.select2-container.select2-container--default .select2-results__option--highlighted[data-selected],.onsale,li.product .woocommerce-loop-product__link:hover .woocommerce-loop-product__title,.qty-btn:hover,.header-mini-cart-count,li.wc-block-grid__product .wc-block-grid__product-onsale',
				},
			]);
		} );
	} );

	wp.customize( 'global_colors_accent_secondary', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_accent_secondary', [
				{
					value: to,
					property: 'background-color',
					selectors: '.head-mast,.site-footer,.page-title,.mm-menu,  .entry-tags a,.tag-cloud-link,.widget_layered_nav_filters a,    .wc-block-active-filters .wc-block-active-filters-list li',
				},
			]);
		} );
	} );

	wp.customize( 'global_colors_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_text', [
				{
					value: to,
					property: 'color',
					selectors: 'body,.site-logo a,.head-mast,.head-outro,.section-subtitle a,.entry-title,.ci-item-title,.navigation a,.navigation .page-numbers,.woocommerce-pagination a,.woocommerce-pagination .page-numbers,.navigation-main a,.widget_meta li a,.widget_pages li a,.widget_categories li a,.widget_archive li a,.widget_nav_menu li a,.widget_product_categories li a,.woocommerce-widget-layered-nav li a,.entry-tags a,.tag-cloud-link,.select2-container.select2-container--default .select2-selection--multiple .select2-selection__rendered,.select2-container.select2-container--default .select2-selection--single.select2-selection__rendered,.instagram-pics li a,li.product .added_to_cart,.single-product div.product .entry-summary .reset_variations,.qty-btn,.wc-tabs a,.woocommerce-MyAccount-navigation .woocommerce-MyAccount-navigation-link a,.woocommerce-MyAccount-content mark,.woocommerce-MyAccount-downloads .download-file a,.woocommerce-Address-title a,.product_list_widget .product-title,.woocommerce-mini-cart-item > a,.header-mini-cart-contents,.widget_layered_nav_filters a,li.wc-block-grid__product .added_to_cart,.wc-block-pagination .wc-block-pagination-page,.wc-block-product-categories-list li a,.wc-block-attribute-filter .wc-block-attribute-filter-list label,.wc-block-active-filters .wc-block-active-filters-list li,label,.label,select:invalid,.comment-metadata,.section-subtitle,.entry-meta,.ci-item-meta,[class^="wp-block"] > figcaption,.wp-block-image figcaption,.wc-block-review-list .wc-block-review-list-item__published-date',
				},
				{
					value: to,
					property: 'border-color',
					selectors: '.quantity-wrap .qty,.qty-btn',
				}
			]);
		} );
	} );

	wp.customize( 'global_colors_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_border', [
				{
					value: to,
					property: 'border-color',
					selectors: 'blockquote,  th, td,  pre,  .no-comments,  .entry-section,  .navigation a,  .navigation .page-numbers,  .woocommerce-pagination a,  .woocommerce-pagination .page-numbers,  .page-links .page-number,  .widget_meta li a,  .widget_pages li a,  .widget_categories li a,  .widget_archive li a,  .widget_nav_menu li a,  .widget_product_categories li a,  .woocommerce-widget-layered-nav li a,  .widget_recent_comments li,  .widget_rss li,  .widget_recent_entries li,  .wp-block-pullquote,  .wp-block-archives li,  .wp-block-categories li,  .wp-block-latest-comments li,  .wp-block-latest-posts li,  .woocommerce-store-notice,  .woocommerce-page .shop_table,  .woocommerce-page .shop_table th,  .woocommerce-page .shop_table td,  .single-product div.product .woocommerce-product-gallery .flex-control-thumbs li img,  .single-product div.product .entry-summary .product_meta,  .wc-tabs,  .wc-tabs a,  .shop_table.woocommerce-cart-form__contents,  .shop_table.woocommerce-cart-form__contents th,  .shop_table.woocommerce-cart-form__contents td,  .woocommerce-checkout .create-account,  .wc_payment_method,  .payment_box,  .woocommerce-order-overview,  .woocommerce-MyAccount-navigation .woocommerce-MyAccount-navigation-link a,  .woocommerce-EditAccountForm fieldset,  .product_list_widget .product-thumb img,  .woocommerce-mini-cart__empty-message,  .woocommerce-mini-cart__total,  .header-mini-cart-contents,  .wc-block-pagination .wc-block-pagination-page,  .wc-block-product-categories-list li a,  .wc-block-attribute-filter .wc-block-attribute-filter-list label',
				},
				{
					value: to,
					property: 'background-color',
					selectors: '.price_slider,.price_slider .ui-slider-range,  hr',
				}
			]);
		} );
	} );

	// Headings
	wp.customize( 'global_colors_h1', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h1', [
				{
					value: to,
					property: 'color',
					selectors: 'h1',
				}
			]);
		} );
	} );

	wp.customize( 'global_colors_h2', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h2', [
				{
					value: to,
					property: 'color',
					selectors: 'h2',
				}
			]);
		} );
	} );

	wp.customize( 'global_colors_h3', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h3', [
				{
					value: to,
					property: 'color',
					selectors: 'h3',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_h4', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h4', [
				{
					value: to,
					property: 'color',
					selectors: 'h4',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_h5', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h5', [
				{
					value: to,
					property: 'color',
					selectors: 'h5',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_h6', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_h6', [
				{
					value: to,
					property: 'color',
					selectors: 'h6',
				}
			])
		} );
	} );

	// Forms
	wp.customize( 'global_colors_forms_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_forms_background', [
				{
					value: to,
					property: 'background-color',
					selectors: 'input[type="text"],input[type="search"],input[type="password"],input[type="date"],input[type="number"],input[type="email"],input[type="url"],input[type="tel"],input[type="time"],select,textarea',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_forms_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_forms_border', [
				{
					value: to,
					property: 'border-color',
					selectors: 'input[type="text"],input[type="search"],input[type="password"],input[type="date"],input[type="number"],input[type="email"],input[type="url"],input[type="tel"],input[type="time"],select,textarea',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_forms_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_forms_text', [
				{
					value: to,
					property: 'color',
					selectors: 'input[type="text"],input[type="search"],input[type="password"],input[type="date"],input[type="number"],input[type="email"],input[type="url"],input[type="tel"],input[type="time"],select,textarea',
				}
			])
		} );
	} );

	// Buttons
	wp.customize( 'global_colors_buttons_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_background', [
				{
					value: to,
					property: 'background-color',
					selectors: '.btn,.button,.navigation-main .nav-button > a,.comment-reply-link,input[type="submit"],input[type="reset"],button[type="submit"],#infinite-handle span button,li.wc-block-grid__product .wp-block-button__link',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_buttons_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_text', [
				{
					value: to,
					property: 'color',
					selectors: '.btn,.button,.navigation-main .nav-button > a,.comment-reply-link,input[type="submit"],input[type="reset"],button[type="submit"],#infinite-handle span button,li.wc-block-grid__product .wp-block-button__link',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_buttons_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_border', [
				{
					value: to,
					property: 'border-color',
					selectors: '.btn,.button,.navigation-main .nav-button > a,.comment-reply-link,input[type="submit"],input[type="reset"],button[type="submit"],#infinite-handle span button,li.wc-block-grid__product .wp-block-button__link',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_buttons_background_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_background_hover', [
				{
					value: to,
					property: 'background-color',
					selectors: '.btn:hover,.button:hover,.navigation-main .nav-button > a:hover,.comment-reply-link:hover,input[type="submit"]:hover,input[type="reset"]:hover,button[type="submit"]:hover,#infinite-handle span button:hover,li.wc-block-grid__product .wp-block-button__link:hover',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_buttons_text_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_text_hover', [
				{
					value: to,
					property: 'color',
					selectors: '.btn:hover,.button:hover,.navigation-main .nav-button > a:hover,.comment-reply-link:hover,input[type="submit"]:hover,input[type="reset"]:hover,button[type="submit"]:hover,#infinite-handle span button:hover,li.wc-block-grid__product .wp-block-button__link:hover',
				}
			])
		} );
	} );

	wp.customize( 'global_colors_buttons_border_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('global_colors_buttons_border_hover', [
				{
					value: to,
					property: 'border-color',
					selectors: '.btn:hover,.button:hover,.navigation-main .nav-button > a:hover,.comment-reply-link:hover,input[type="submit"]:hover,input[type="reset"]:hover,button[type="submit"]:hover,#infinite-handle span button:hover,li.wc-block-grid__product .wp-block-button__link:hover',
				}
			])
		} );
	} );


	//
	// Typography
	//
	wp.customize( 'global_typo_body', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_body',
				'body',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h1', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h1',
				'h1',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h2', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h2',
				'h2',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h3', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h3',
				'h3, .widget-title',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h4', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h4',
				'h4',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h5', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h5',
				'h5',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_h6', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_h6',
				'h6',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_form_labels', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_form_labels',
				'form label, form .label',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_form_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_form_text',
				'input, textarea, select',
				to,
			);
		} );
	} );

	wp.customize( 'global_typo_buttons', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'global_typo_buttons',
				'.btn, .button, .entry-more-btn, .ci-item-btn, button[type="submit"], input[type="submit"], input[type="reset"], .comment-reply-link',
				to,
			);
		} );
	} );

})( jQuery );
