/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Customizer preview changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ( $ ) {
	//
	// Layout
	//
	wp.customize( 'header_layout_type', function ( value ) {
		value.bind( function ( to ) {
			var $header = $( '.site-header' );
			if ( to === 'normal' ) {
				$header.removeClass( 'header-fixed' );
			} else if ( to === 'transparent' ) {
				$header.addClass( 'header-fixed' );
			}
		} );
	} );

	wp.customize( 'header_layout_is_full_width', function ( value ) {
		value.bind( function ( to ) {
			if ( to ) {
				$( '.site-header' ).addClass( 'header-fullwidth' );
			} else {
				$( '.site-header' ).removeClass( 'header-fullwidth' );
			}
		} );
	} );

	wp.customize( 'header_layout_height', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createSpacingControlStyles(
				'header_layout_height',
				'.head-mast',
				'padding',
				to
			);
		} );
	} );

	wp.customize( 'header_layout_menu_height', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createSpacingControlStyles(
				'header_layout_menu_height',
				'.head-outro',
				'padding',
				to
			);
		} );
	} );


	//
	// Colors
	//
	wp.customize( 'header_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_background', [
					{
						value: to || '',
						property: 'background-color',
						selectors: '.head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_border', [
					{
						value: '1px solid ' + to,
						property: 'border-bottom',
						selectors: '.head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_text', [
					{
						value: to,
						property: 'color',
						selectors: '.head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_logo', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_logo', [
					{
						value: to,
						property: 'color',
						selectors: '.site-logo a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_logo_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_logo_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.site-logo a:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_menu_container_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_menu_container_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-outro',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_menu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_menu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.head-outro, .navigation-main > li > a, mobile-nav-trigger',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_menu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_menu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-main > li:hover > a,.navigation-main > li > a:focus,.mobile-nav-trigger:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_menu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_menu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_menu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_menu_item_active_background', [
					{
						value: to || 'transparent',
						property: 'background-color',
						selectors: '.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a',
					},
					{
						value: to ? '15px' : '0',
						property: 'padding-left',
						selectors: '.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a',
					},
					{
						value: to ? '15px' : '0',
						property: 'padding-right',
						selectors: '.navigation-main > .current-menu-item > a,.navigation-main > .current-menu-parent > a,.navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.navigation-main ul',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-main li li a ',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-main li li:hover > a,.navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_item_hover_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_item_hover_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.navigation-main li li:hover > a,.navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-main li .current-menu-item > a,.navigation-main li .current-menu-parent > a,.navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_colors_submenu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_colors_submenu_item_active_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.navigation-main li .current-menu-item > a,.navigation-main li .current-menu-parent > a,.navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );


	//
	// Transparent header colors
	//
	wp.customize( 'header_transparent_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_background', [
					{
						value: to || '',
						property: 'background-color',
						selectors: '.header-fixed .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_border', [
					{
						value: '1px solid ' + to,
						property: 'border-bottom',
						selectors: '.header-fixed .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_text', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_logo', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_logo', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .site-logo a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_logo_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_logo_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .site-logo a:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_menu_container_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_menu_container_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.header-fixed .head-outro',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_menu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_menu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main > li > a, .header-fixed .mobile-nav-trigger',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_menu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_menu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main > li:hover > a,.header-fixed .navigation-main > li > a:focus, .header-fixed .mobile-nav-trigger:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_menu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_menu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main > .current-menu-item > a,.header-fixed .navigation-main > .current-menu-parent > a,.header-fixed .navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_menu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_menu_item_active_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.header-fixed .navigation-main > .current-menu-item > a,.header-fixed .navigation-main > .current-menu-parent > a,.header-fixed .navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.header-fixed .navigation-main ul',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main li li a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main li li:hover > a,.header-fixed .navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_item_hover_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_item_hover_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.header-fixed .navigation-main li li:hover > a,.header-fixed .navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.header-fixed .navigation-main li .current-menu-item > a,.header-fixed .navigation-main li .current-menu-parent > a,.header-fixed .navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_transparent_colors_submenu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_transparent_colors_submenu_item_active_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.header-fixed .navigation-main li .current-menu-item > a,.header-fixed .navigation-main li .current-menu-parent > a,.header-fixed .navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );


	//
	// Sticky header colors
	//
	wp.customize( 'header_sticky_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_background', [
					{
						value: to || '',
						property: 'background-color',
						selectors: '.head-stuck .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_border', [
					{
						value: '1px solid ' + to,
						property: 'border-bottom',
						selectors: '.head-stuck .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_text', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .head-mast',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_logo', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_logo', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .site-logo a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_logo_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_logo_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .site-logo a:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_menu_container_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_menu_container_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-stuck .head-outro',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_menu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_menu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main > li > a, .head-stuck .mobile-nav-trigger',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_menu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_menu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main > li:hover > a,.head-stuck .navigation-main > li > a:focus, .head-stuck .mobile-nav-trigger:hover',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_menu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_menu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main > .current-menu-item > a,.head-stuck .navigation-main > .current-menu-parent > a,.head-stuck .navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_menu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_menu_item_active_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-stuck .navigation-main > .current-menu-item > a,.head-stuck .navigation-main > .current-menu-parent > a,.head-stuck .navigation-main > .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-stuck .navigation-main ul',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_item_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_item_link', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main li li a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_item_hover', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_item_hover', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main li li:hover > a,.head-stuck .navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_item_hover_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_item_hover_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-stuck .navigation-main li li:hover > a,.head-stuck .navigation-main li li > a:focus',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_item_active', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_item_active', [
					{
						value: to,
						property: 'color',
						selectors: '.head-stuck .navigation-main li .current-menu-item > a,.head-stuck .navigation-main li .current-menu-parent > a,.head-stuck .navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_sticky_colors_submenu_item_active_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_sticky_colors_submenu_item_active_background', [
					{
						value: to,
						property: 'background-color',
						selectors: '.head-stuck .navigation-main li .current-menu-item > a,.head-stuck .navigation-main li .current-menu-parent > a,.head-stuck .navigation-main li .current-menu-ancestor > a',
					}
				]
			);
		} );
	} );


	//
	// Mobile nav colors
	//
	wp.customize( 'header_mobile_nav_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_mobile_nav_colors_background', [
					{
						value: to || '',
						property: 'background-color',
						selectors: '.navigation-mobile-wrap',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_mobile_nav_colors_link', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_mobile_nav_colors_link', [
					{
						value: to,
						property: 'color',
						selectors: '.navigation-mobile-dismiss, .navigation-mobile a',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_mobile_nav_colors_arrows', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_mobile_nav_colors_arrows', [
					{
						value: to,
						property: 'color',
						selectors: '.menu-item-sub-menu-toggle',
					}
				]
			);
		} );
	} );

	wp.customize( 'header_mobile_nav_colors_border', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('header_mobile_nav_colors_border', [
					{
						value: to,
						property: 'border-color',
						selectors: '.navigation-mobile a',
					}
				]
			);
		} );
	} );


	//
	// Typography
	//
	wp.customize( 'header_typo_logo', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'header_typo_logo',
				'.site-logo',
				to,
			);
		} );
	} );

	wp.customize( 'header_typo_tagline', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'header_typo_tagline',
				'.site-tagline',
				to,
			);
		} );
	} );

	wp.customize( 'header_typo_menu', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'header_typo_menu',
				'.navigation-main a, .navigation-main li li a, .head-outro',
				to,
			);
		} );
	} );

	wp.customize( 'header_typo_submenu', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createTypographyStyles(
				'header_typo_submenu',
				'.navigation-main li li a',
				to,
			);
		} );
	} );

})( jQuery );
