/**
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Customizer preview changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ( $ ) {
	//
	// Lightbox
	//
	wp.customize( 'utilities_lightbox', function ( value ) {
		value.bind( function ( to ) {
			if ( to ) {
				$( ".gutenbee-lightbox, a[data-lightbox^='gal']" ).magnificPopup( {
					type: 'image',
					mainClass: 'mfp-with-zoom',
					gallery: {
						enabled: true
					},
					zoom: {
						enabled: true
					},
					image: {
						titleSrc: function ( item ) {
							var $item          = item.el;
							var $parentCaption = $item.parents( '.wp-caption' ).first();

							if ( $item.attr( 'title' ) ) {
								return $item.attr( 'title' );
							}

							if ( $parentCaption ) {
								return $parentCaption.find( '.wp-caption-text' ).text();
							}
						},
					},
				} );
			} else {
				$( ".gutenbee-lightbox, a[data-lightbox^='gal']" ).off( 'click' );
			}
		} );
	} );


	//
	// Back to top button
	//
	wp.customize( 'button_top_position', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createSpacingControlStyles(
				'button_top_position',
				'.btn-to-top',
				'position',
				to,
			);
		} );
	} );

	wp.customize( 'button_top_colors_background', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('button_top_colors_background', [
				{
					value: to || 'white',
					property: 'background',
					selectors: '.btn-to-top, .btn-to-top:hover',
				}
			]);
		} );
	} );

	wp.customize( 'button_top_colors_text', function ( value ) {
		value.bind( function ( to ) {
			GUTENBEE_PREVIEW_SCRIPTS.createStyleSheet('button_top_colors_text', [
				{
					value: to || 'black',
					property: 'color',
					selectors: '.btn-to-top, .btn-to-top:hover',
				}
			]);
		} );
	} );

})( jQuery );
