<?php
/**
 * Gutenbee onboarding related code.
 */
if ( ! defined( 'GUTENBEE_WHITELABEL' ) || false === (bool) GUTENBEE_WHITELABEL ) {
	add_action( 'ocdi/after_import', 'gutenbee_ocdi_after_import_setup' );
}

add_filter( 'ocdi/timeout_for_downloading_import_file', 'gutenbee_ocdi_download_timeout' );
function gutenbee_ocdi_download_timeout( $timeout ) {
	return 60;
}

add_filter( 'ocdi/plugin_intro_text', 'gutenbee_ocdi_intro_text' );
function gutenbee_ocdi_intro_text( $html ) {
	$sample_content_url = gutenbee_documentation_url() . '#sample-content';

	ob_start();
	?>
	<p><?php
		/* translators: %s is a url. */
		echo wp_kses_post( sprintf( __( 'Looking for the GutenBee sample content files? Download them <a href="%s" target="_blank">here</a>.', 'gutenbee' ), esc_url( $sample_content_url ) ) );
	?></p>
	<hr>
	<?php

	$append_html = ob_get_clean();

	return $html . $append_html;
}

function gutenbee_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu = get_term_by( 'name', 'Main', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'menu-1' => $main_menu->term_id,
	) );

	update_option( 'show_on_front', 'posts' );

	// Try to force a term recount.
	// wp_defer_term_counting( false ) doesn't work properly as there are post imported from different AJAX requests.
	$taxonomies = get_taxonomies( array(), 'names' );
	foreach ( $taxonomies as $taxonomy ) {
		$terms             = get_terms( $taxonomy, array( 'hide_empty' => false ) );
		$term_taxonomy_ids = wp_list_pluck( $terms, 'term_taxonomy_id' );

		wp_update_term_count( $term_taxonomy_ids, $taxonomy );
	}
}

function gutenbee_get_theme_required_plugins() {
	return apply_filters( 'gutenbee_theme_required_plugins', array() );
}

function gutenbee_get_theme_recommended_plugins() {
	return apply_filters( 'gutenbee_theme_recommended_plugins', array(
		'gutenbee'              => array(
			'title'       => __( 'GutenBee - The plugin', 'gutenbee' ),
			'description' => __( 'Premium blocks for WordPress.', 'gutenbee' ),
		),
		'woocommerce'           => array(
			'title'       => __( 'WooCommerce', 'gutenbee' ),
			'description' => __( 'Sell anything, beautifully.', 'gutenbee' ),
		),
		'maxslider'             => array(
			'title'       => __( 'MaxSlider', 'gutenbee' ),
			'description' => __( 'Add a custom responsive slider to any page of your website.', 'gutenbee' ),
		),
		'audioigniter'          => array(
			'title'       => __( 'AudioIgniter', 'gutenbee' ),
			'description' => __( 'Probably the most flexible music player plugin for WordPress.', 'gutenbee' ),
		),
		'wpforms-lite'          => array(
			'title'       => __( 'Contact Form by WPForms', 'gutenbee' ),
			'description' => __( 'Drag & Drop Form Builder for WordPress.', 'gutenbee' ),
			'plugin_file' => 'wpforms.php',
			'is_callable' => 'wpforms',
		),
		'one-click-demo-import' => array(
			'title'              => __( 'One Click Demo Import', 'gutenbee' ),
			'description'        => __( 'Import your demo content, widgets and theme settings with one click.', 'gutenbee' ),
			'required_by_sample' => true,
		),
	) );
}

add_action( 'init', 'gutenbee_onboarding_page_init' );
function gutenbee_onboarding_page_init() {
	$data = array(
		'show_page'                => true,
		'description'              => __( 'Perfect companion theme for GutenBee - The plugin and Project Gutenberg.', 'gutenbee' ),
		'logo_src'                 => get_theme_file_uri( '/inc/assets/images/gutenbee_logo.svg' ),
		'logo_url'                 => 'https://gutenbee.com/',
		'default_tab'              => 'recommended_plugins',
		'tabs'                     => array(
			'required_plugins' => '',
		),
		'required_plugins_page'    => array(
			'plugins' => gutenbee_get_theme_required_plugins(),
		),
		'recommended_plugins_page' => array(
			'plugins' => gutenbee_get_theme_recommended_plugins(),
		),
		'support_page'             => array(
			'sections' => array(
				'documentation' => array(
					'title'       => __( 'Theme Documentation', 'gutenbee' ),
					'description' => __( "If you don't want to import our demo sample content, just visit this page and learn how to set things up individually.", 'gutenbee' ),
					'link_url'    => 'https://gutenbee.com/docs/',
				),
				'support'       => array(
					'title'       => __( 'Request Support', 'gutenbee' ),
					'description' => __( 'Got stuck? No worries, just visit our support page, submit your ticket and we will be there for you within 24 hours.', 'gutenbee' ),
					'link_url'    => 'https://wordpress.org/support/theme/gutenbee/',
				),
			),
		),
	);

	$onboarding = new Gutenbee_Onboarding_Page();
	$onboarding->init( apply_filters( 'gutenbee_onboarding_page_array', $data ) );
}

/**
 * User onboarding.
 */
require_once get_theme_file_path( '/inc/onboarding/onboarding-page.php' );
