<?php
/**
 * WooCommerce integration
 */

/**
 * Disable the default WooCommerce stylesheet.
 */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Enable WooCommerce product gallery and set default settings
 */
add_action( 'after_setup_theme', 'gutenbee_woocommerce_activation' );
function gutenbee_woocommerce_activation() {
	add_theme_support( 'woocommerce', array(
		'thumbnail_image_width'         => 750,
		'single_image_width'            => 560,
		'gallery_thumbnail_image_width' => 150,
		'product_grid'                  => array(
			'default_columns' => 3,
			'min_columns'     => 1,
			'max_columns'     => 4,
		),
	) );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-slider' );
	add_theme_support( 'wc-product-gallery-lightbox' );
}

add_filter( 'woocommerce_cross_sells_total', 'gutenbee_woocommerce_crosssells_total' );
function gutenbee_woocommerce_crosssells_total( $limit ) {
	return 4;
}

add_filter( 'woocommerce_output_related_products_args', 'gutenbee_woocommerce_output_related_products_args' );
function gutenbee_woocommerce_output_related_products_args( $args ) {
	$args['posts_per_page'] = 3;
	$args['columns']        = 3;

	return $args;
}

// It looks like actions 'after_setup_theme' and 'init' are too early in order for get_theme_mod() values
// to be previewed from the customizer.
add_action( 'wp', 'gutenbee_woocommerce_maybe_remove_related' );
function gutenbee_woocommerce_maybe_remove_related() {
	if ( ! get_theme_mod( 'woocommerce_product_related', gutenbee_customizer_defaults( 'woocommerce_product_related' ) ) ) {
		remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
	}
}


add_filter( 'woocommerce_upsells_total', 'gutenbee_woocommerce_upsells_total' );
add_filter( 'woocommerce_upsells_columns', 'gutenbee_woocommerce_upsells_total' );
function gutenbee_woocommerce_upsells_total() {
	return 3;
}

add_action( 'wp', 'gutenbee_hero_hide_woocommerce_shop_title' );
/**
 * This function needs to be called on 'wp' or later, as gutenbee_get_hero_data() utilizes WC conditional tags.
 * If a need arises to call earlier, then the shop's page ID must be passed explicitly to gutenbee_get_hero_data().
 */
function gutenbee_hero_hide_woocommerce_shop_title() {
	if ( ( is_shop() || is_product_taxonomy() ) && gutenbee_get_post_meta( wc_get_page_id( 'shop' ), 'gutenbee_hide_single_title', 0 ) ) {
		add_filter( 'woocommerce_show_page_title', '__return_false' );
		remove_action( 'woocommerce_archive_description', 'woocommerce_taxonomy_archive_description', 10 );
	}
}

add_filter( 'woocommerce_breadcrumb_defaults', 'gutenbee_woocommerce_breadcrumb_defaults' );
function gutenbee_woocommerce_breadcrumb_defaults( $defaults ) {
	return array_merge( $defaults, array(
		'delimiter'   => '<span class="woocommerce-breadcrumb-separator"> </span>',
		'wrap_before' => '<div class="row"><div class="col-12"><nav class="woocommerce-breadcrumb">',
		'wrap_after'  => '</nav></div></div>',
	) );
}

add_filter( 'woocommerce_add_to_cart_fragments', 'gutenbee_woocommerce_minicart_button_fragment' );
/**
 * Cart Fragments.
 *
 * Ensure cart contents update when products are added to the cart via AJAX.
 *
 * @param array $fragments Fragments to refresh via AJAX.
 * @return array Fragments to refresh via AJAX.
 */
function gutenbee_woocommerce_minicart_button_fragment( $fragments ) {
	if ( function_exists( 'gutenbee_minicart_button_trigger_text' ) ) {
		ob_start();
		gutenbee_minicart_button_trigger_text();
		$fragments['span.header-mini-cart-trigger-text'] = ob_get_clean();
	}

	return $fragments;
}

add_action( 'woocommerce_before_add_to_cart_quantity', 'gutenbee_display_quantity_minus' );
/**
 * Add minus button before the quantity input.
 */
function gutenbee_display_quantity_minus() {
	echo '<div class="quantity-wrap"><button type="button" class="qty-btn qty-minus">-</button>';
}

add_action( 'woocommerce_after_add_to_cart_quantity', 'gutenbee_display_quantity_plus' );
/**
 * Add plus button after the quantity input.
 */
function gutenbee_display_quantity_plus() {
	echo '<button type="button" class="qty-btn qty-plus" >+</button></div>';
}
